@@ -1,11 +1,21 @@
-from .resources import DbtRpcClient, dbt_rpc_resource, local_dbt_rpc_resource
+from .resources import (
+    DbtRpcResource,
+    DbtRpcSyncResource,
+    dbt_rpc_resource,
+    dbt_rpc_sync_resource,
+    local_dbt_rpc_resource,
+)
 from .solids import (
     create_dbt_rpc_run_sql_solid,
     dbt_rpc_compile_sql,
+    dbt_rpc_docs_generate,
+    dbt_rpc_docs_generate_and_wait,
     dbt_rpc_run,
     dbt_rpc_run_and_wait,
     dbt_rpc_run_operation,
     dbt_rpc_run_operation_and_wait,
+    dbt_rpc_seed,
+    dbt_rpc_seed_and_wait,
     dbt_rpc_snapshot,
     dbt_rpc_snapshot_and_wait,
     dbt_rpc_snapshot_freshness,
