@@ -1,12 +1,15 @@
 import responses
-from dagster import ModeDefinition, execute_solid
 from dagster_dbt import (
     DbtRpcOutput,
+    dbt_rpc_docs_generate,
+    dbt_rpc_docs_generate_and_wait,
     dbt_rpc_resource,
     dbt_rpc_run,
     dbt_rpc_run_and_wait,
     dbt_rpc_run_operation,
     dbt_rpc_run_operation_and_wait,
+    dbt_rpc_seed,
+    dbt_rpc_seed_and_wait,
     dbt_rpc_snapshot,
     dbt_rpc_snapshot_and_wait,
     dbt_rpc_snapshot_freshness,
@@ -15,6 +18,8 @@ from dagster_dbt import (
     dbt_rpc_test_and_wait,
 )
 
+from dagster import ModeDefinition, execute_solid
+
 
 def test_dbt_rpc_snapshot(rsps):
     host = "0.0.0.0"
@@ -31,7 +36,9 @@ def test_dbt_rpc_snapshot(rsps):
         dbt_rpc_snapshot,
         mode_def=ModeDefinition(name="unittest", resource_defs={"dbt_rpc": dbt_rpc_resource}),
         input_values={"start_after": None},
-        run_config={"resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},},
+        run_config={
+            "resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},
+        },
     )
 
     assert result.success
@@ -53,7 +60,9 @@ def test_dbt_rpc_run(rsps):
         dbt_rpc_run,
         mode_def=ModeDefinition(name="unittest", resource_defs={"dbt_rpc": dbt_rpc_resource}),
         input_values={"start_after": None},
-        run_config={"resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},},
+        run_config={
+            "resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},
+        },
     )
 
     assert result.success
@@ -75,7 +84,9 @@ def test_dbt_rpc_test(rsps):
         dbt_rpc_test,
         mode_def=ModeDefinition(name="unittest", resource_defs={"dbt_rpc": dbt_rpc_resource}),
         input_values={"start_after": None},
-        run_config={"resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},},
+        run_config={
+            "resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},
+        },
     )
 
     assert result.success
@@ -129,6 +140,54 @@ def test_dbt_rpc_snapshot_freshness(rsps):
     assert result.output_value("request_token") == "1234-xo-xo"
 
 
+def test_dbt_rpc_seed(rsps):
+    host = "0.0.0.0"
+    port = 8580
+
+    rsps.add(
+        method=responses.POST,
+        url=f"http://{host}:{port}/jsonrpc",
+        status=201,
+        json={"result": {"request_token": "1234-xo-xo"}},
+    )
+
+    result = execute_solid(
+        dbt_rpc_seed,
+        mode_def=ModeDefinition(name="unittest", resource_defs={"dbt_rpc": dbt_rpc_resource}),
+        input_values={"start_after": None},
+        run_config={
+            "resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},
+        },
+    )
+
+    assert result.success
+    assert result.output_value("request_token") == "1234-xo-xo"
+
+
+def test_dbt_rpc_docs_generate(rsps):
+    host = "0.0.0.0"
+    port = 8580
+
+    rsps.add(
+        method=responses.POST,
+        url=f"http://{host}:{port}/jsonrpc",
+        status=201,
+        json={"result": {"request_token": "1234-xo-xo"}},
+    )
+
+    result = execute_solid(
+        dbt_rpc_docs_generate,
+        mode_def=ModeDefinition(name="unittest", resource_defs={"dbt_rpc": dbt_rpc_resource}),
+        input_values={"start_after": None},
+        run_config={
+            "resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},
+        },
+    )
+
+    assert result.success
+    assert result.output_value("request_token") == "1234-xo-xo"
+
+
 def test_dbt_rpc_run_and_wait(rsps, non_terminal_poll_result, terminal_poll_result):
     host = "0.0.0.0"
     port = 8580
@@ -324,3 +383,79 @@ def test_dbt_rpc_test_and_wait(rsps, non_terminal_poll_result, terminal_poll_res
 
     assert result.success
     assert isinstance(result.output_value("result"), DbtRpcOutput)
+
+
+def test_dbt_rpc_seed_and_wait(rsps, non_terminal_poll_result, terminal_poll_result):
+    host = "0.0.0.0"
+    port = 8580
+
+    rsps.add(
+        method=responses.POST,
+        url=f"http://{host}:{port}/jsonrpc",
+        status=201,
+        json={"result": {"request_token": "1234-xo-xo"}},
+    )
+
+    rsps.add(
+        method=responses.POST,
+        url=f"http://{host}:{port}/jsonrpc",
+        status=201,
+        json=non_terminal_poll_result,
+    )
+
+    rsps.add(
+        method=responses.POST,
+        url=f"http://{host}:{port}/jsonrpc",
+        status=201,
+        json=terminal_poll_result,
+    )
+
+    result = execute_solid(
+        dbt_rpc_seed_and_wait,
+        mode_def=ModeDefinition(name="unittest", resource_defs={"dbt_rpc": dbt_rpc_resource}),
+        input_values={"start_after": None},
+        run_config={
+            "resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},
+        },
+    )
+
+    assert result.success
+    assert isinstance(result.output_value("result"), DbtRpcOutput)
+
+
+def test_dbt_rpc_docs_generate_and_wait(rsps, non_terminal_poll_result, terminal_poll_result):
+    host = "0.0.0.0"
+    port = 8580
+
+    rsps.add(
+        method=responses.POST,
+        url=f"http://{host}:{port}/jsonrpc",
+        status=201,
+        json={"result": {"request_token": "1234-xo-xo"}},
+    )
+
+    rsps.add(
+        method=responses.POST,
+        url=f"http://{host}:{port}/jsonrpc",
+        status=201,
+        json=non_terminal_poll_result,
+    )
+
+    rsps.add(
+        method=responses.POST,
+        url=f"http://{host}:{port}/jsonrpc",
+        status=201,
+        json=terminal_poll_result,
+    )
+
+    result = execute_solid(
+        dbt_rpc_docs_generate_and_wait,
+        mode_def=ModeDefinition(name="unittest", resource_defs={"dbt_rpc": dbt_rpc_resource}),
+        input_values={"start_after": None},
+        run_config={
+            "resources": {"dbt_rpc": {"config": {"host": host, "port": port}}},
+        },
+    )
+
+    assert result.success
+    assert isinstance(result.output_value("result"), DbtRpcOutput)
